Execute SASPy function if session is active
Source:R/connection-checks.R
execute_if_connection_active.RdExecutes the code passed to it if the connection is active and provides a more helpful error message if no connection is active.
Usage
execute_if_connection_active(code, call = rlang::caller_env())