sas_file_copy: Copy a file on SAS

View source: R/file-copy.R

sas_file_copyR Documentation

Copy a file on SAS

Description

Copies a file on the remote SAS server. Is analogous to file.copy(), but for the remote SAS server.

Usage

sas_file_copy(from_path, to_path)

Arguments

from_path

string; Path of file on remote SAS server to be copied.

to_path

string; Path of file on remote SAS server to copy to.

Value

logical; value indicating if the operation succeeded.

See Also

Other file management functions: sas_file_download(), sas_file_exists(), sas_file_remove(), sas_file_upload(), sas_list()

Examples


# connect to SAS
sas_connect()

# create an example file
local_path <- tempfile(fileext = ".txt")
cat("some example text", file = tempfile_path)

sas_path <- readline(
  "Please provide the full path to upload an example file to (e.g., ~/example.txt)."
)
sas_file_upload(local_path, sas_path)

from_path <- sas_path
to_path <- readline(
  "Please provide the full path to copy the example file to (e.g., ~/example_copy.txt)."
)
sas_file_copy(from_path, to_path)

# cleanup
unlink(local_path)
sas_file_remove(from_path)
sas_file_remove(to_path)


sasquatch documentation built on Feb. 28, 2026, 1:07 a.m.