sas_file_exists: Check if file on SAS exists

View source: R/file-exists.R

sas_file_existsR Documentation

Check if file on SAS exists

Description

Checks if a file exists on the remote SAS server. Is analogous to file.exists(), but for the remote SAS server.

Usage

sas_file_exists(path)

Arguments

path

string; Path of file on remote SAS server.

Value

logical; value indicating if the operation succeeded.

See Also

Other file management functions: sas_file_copy(), sas_file_download(), sas_file_remove(), sas_file_upload(), sas_list()

Examples


# connect to SAS
sas_connect()

# create an example file
local_path <- tempfile(fileext = ".txt")
cat("some example text", file = tempfile_path)

sas_path <- readline(
  "Please provide the full path to upload an example file to (e.g., ~/example.txt)."
)
sas_file_upload(local_path, sas_path)

sas_file_exists(sas_path)

# cleanup
unlink(local_path)
sas_file_remove(sas_path)


sasquatch documentation built on Feb. 28, 2026, 1:07 a.m.