Skip to contents

Deletes a file or directory from the remote SAS server. Is analogous to file.remove(), but for the remote SAS server.

Usage

sas_file_remove(path)

Arguments

path

string; Path of file on remote SAS server to be deleted.

Value

logical; value indicating if the operation succeeded.

See also

Examples

if (FALSE) { # interactive()
# connect to SAS
sas_connect()

# create an example file
local_path <- tempfile(fileext = ".txt")
cat("some example text", file = tempfile_path)

sas_path <- readline(
  "Please provide the full path to upload an example file to (e.g., ~/example.txt)."
)
sas_file_upload(local_path, sas_path)

sas_file_remove(sas_path)

# cleanup
unlink(local_path)
}