sas_run_selected: Execute selected SAS code

View source: R/run-selected.R

sas_run_selectedR Documentation

Execute selected SAS code

Description

Execute selected SAS code in current session and render html output as SAS widget. See vignette("overview") for more information on how to utilize the addin within RStudio or Positron.

Usage

sas_run_selected()

Value

htmlwidget; HTML5 output.

See Also

Other code execution functions: sas_run_file(), sas_run_string()

Examples


sas_connect()

# highlight something in the active editor of RStudio or Positron

sas_run_selected()


sasquatch documentation built on Feb. 28, 2026, 1:07 a.m.