execute_if_connection_active: Execute SASPy function if session is active

View source: R/connection-checks.R

execute_if_connection_activeR Documentation

Execute SASPy function if session is active

Description

Executes the code passed to it if the connection is active and provides a more helpful error message if no connection is active.

Usage

execute_if_connection_active(code, call = rlang::caller_env())

Details

The SAS connection is asynchronous so it can become inactive without the user knowing. When the connection is inactive and an action is preformed it will check the connection and raise an error.


sasquatch documentation built on Feb. 28, 2026, 1:07 a.m.