View source: R/connection-checks.R
| execute_if_connection_active | R Documentation |
Executes the code passed to it if the connection is active and provides a more helpful error message if no connection is active.
execute_if_connection_active(code, call = rlang::caller_env())
The SAS connection is asynchronous so it can become inactive without the user knowing. When the connection is inactive and an action is preformed it will check the connection and raise an error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.