View source: R/saspy-install.R
| install_saspy | R Documentation |
Installs the SASPy package and its dependencies within a
virtual Python environment.
Behavior was derived from tensorflow::install_tensorflow().
install_saspy(
method = c("auto", "virtualenv", "conda"),
conda = "auto",
envname = "r-saspy",
extra_packages = NULL,
restart_session = TRUE,
conda_python_version = NULL,
...,
pip_ignore_installed = FALSE,
new_env = identical(envname, "r-saspy"),
python_version = NULL
)
method |
By default, |
conda |
The path to a conda executable. Use |
envname |
The name, or full path, of the environment in which Python packages are to be installed. |
extra_packages |
Additional packages to install. |
restart_session |
Restart session? |
conda_python_version |
Passed to conda (only applicable if |
... |
other arguments passed to |
pip_ignore_installed |
Should pip ignore installed python packages and reinstall all already installed python packages? |
new_env |
If |
python_version |
Select the Python that will be used to create the virtualenv. Pass a string with
version constraints like |
No return value.
configure_saspy()
install_saspy(
envname = "new-sasquatch-env",
extra_packages = c("matplotlib", "numpy"),
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.