| sas_file_exists | R Documentation |
Checks if a file exists on the remote SAS server. Is analogous to
file.exists(), but for the remote SAS server.
sas_file_exists(path)
path |
string; Path of file on remote SAS server. |
logical; value indicating if the operation succeeded.
Other file management functions:
sas_file_copy(),
sas_file_download(),
sas_file_remove(),
sas_file_upload(),
sas_list()
# connect to SAS
sas_connect()
# create an example file
local_path <- tempfile(fileext = ".txt")
cat("some example text", file = tempfile_path)
sas_path <- readline(
"Please provide the full path to upload an example file to (e.g., ~/example.txt)."
)
sas_file_upload(local_path, sas_path)
sas_file_exists(sas_path)
# cleanup
unlink(local_path)
sas_file_remove(sas_path)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.