Deletes a file or directory from the remote SAS server. Is analogous to
file.remove(), but for the remote SAS server.
See also
Other file management functions:
sas_file_copy(),
sas_file_download(),
sas_file_exists(),
sas_file_upload(),
sas_list()
Examples
if (FALSE) { # interactive()
# connect to SAS
sas_connect()
# create an example file
local_path <- tempfile(fileext = ".txt")
cat("some example text", file = tempfile_path)
sas_path <- readline(
"Please provide the full path to upload an example file to (e.g., ~/example.txt)."
)
sas_file_upload(local_path, sas_path)
sas_file_remove(sas_path)
# cleanup
unlink(local_path)
}