| sas_from_r | R Documentation |
Converts R table into a table in the current SAS session. R tables must only have logical, integer, double, factor, character, POSIXct, or Date class columns.
sas_from_r(x, table_name, libref = "WORK", factors_as_strings = TRUE)
x |
|
table_name |
string; Name of table to be created in SAS. |
libref |
string; Name of libref to store SAS table within. |
factors_as_strings |
logical; If |
SAS only has two data types (numeric and character). Data types are converted as follows:
logical -> numeric
integer -> numeric
double -> numeric
factor -> character
character -> character
POSIXct -> numeric (datetime; timezones are lost)
Date -> numeric (date)
data.frame; x.
sas_to_r()
sas_connect()
sas_from_r(mtcars, "mtcars")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.