sas_get_session: Get current SAS session

View source: R/get-session.R

sas_get_sessionR Documentation

Get current SAS session

Description

Returns the current SAS session, which can be used to extend sasquatch functionality or access the current session within Python.

Usage

sas_get_session()

Details

Extending sasquatch functionality

SASPy has a wealth of functionality, some of which have not all been implemented within sasquatch. sas_get_session() offers a gateway to unimplemented functionality within the SASsession class.

Using Python

When utilizing Python, R, and SAS, start the session within R using sas_connect() and utilize reticulate to pass the saspy.sasbase.SASsession object to Python.

Value

saspy.sasbase.SASsession; Current SAS session.

See Also

Other session management functions: sas_connect(), sas_disconnect()

Examples


sas_connect()

sas_get_session()


sasquatch documentation built on Feb. 28, 2026, 1:07 a.m.