| sas_get_session | R Documentation |
Returns the current SAS session, which can be used to extend sasquatch
functionality or access the current session within Python.
sas_get_session()
sasquatch functionalitySASPy has a wealth of functionality, some of which have not all been
implemented within sasquatch. sas_get_session() offers a gateway to
unimplemented functionality within the
SASsession class.
When utilizing Python, R, and SAS, start the session within R using
sas_connect() and utilize reticulate to pass the
saspy.sasbase.SASsession object to Python.
saspy.sasbase.SASsession; Current SAS session.
Other session management functions:
sas_connect(),
sas_disconnect()
sas_connect()
sas_get_session()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.